:mod:`xoutil.fs.path` -- Path utilities
=======================================

.. automodule:: xoutil.fs.path
   :members: join, fix_encoding, normalize_path, shorten_module_filename,
             shorten_user, rtrim
